@@ -100,7 +100,7 @@ class BaseAuthBackend(ABC):
     def application(self) -> Application:
         if not self._application:
             self.getToken()
-
+            
         return self._application
 
 
@@ -109,6 +109,8 @@ class BaseAuthBackend(ABC):
             if self.token is None:
                 try:
                     self.token = self.fetchToken()
+                except ConnectionResetError:
+                    raise Exception(f"We couldn't connect to the Herre instance at {self.base_url}")     
                 except:
                     logger.error(f"Couldn't fetch Token with config {self.config}")
                     raise
