@@ -43,12 +43,9 @@ class BaseBergen:
 
 
     def __init__(self, auth: BaseAuthBackend, config: ArkitektConfig , 
-            auto_negotiate=True,
             bind=True,
             log=logging.INFO,
             jupyter=False,
-            force_sync = False,
-            loop = None,
             client_type: ClientType = ClientType.CLIENT,
             log_stream=False,
             **kwargs) -> None:
@@ -58,20 +55,7 @@ class BaseBergen:
         else:
             setLogging(log, log_stream=log_stream)
 
-
-        self.running_in_sync = force_sync
-        
-        self.loop = loop or asyncio.get_event_loop()
-        if self.loop.is_running():
-            if self.running_in_sync:
-                logger.warn("force_insync within event-loop. unexpected errors might be happening")
-                import nest_asyncio
-                nest_asyncio.apply(self.loop)
-            self.loop_is_running = True
-        else:
-            self.loop_is_running = False
-
-        
+       
         if bind: 
             # We only import this here for typehints
             from bergen.registries.client import set_current_client
@@ -102,9 +86,6 @@ class BaseBergen:
         self.negotiate_additionals = {}
         super().__init__() 
 
-    def getLoopAndContext(self):
-        return self.loop, self.running_in_sync    
-
 
     @property
     def transcript(self):
@@ -188,6 +169,8 @@ class BaseBergen:
         return provider
     
     async def negotiate_async(self):
+        self.loop = asyncio.get_event_loop()
+
         from bergen.queries.initiation import NEGOTIATION_GQL
         from bergen.registries.datapoint import get_datapoint_registry
 
@@ -271,7 +254,11 @@ class BaseBergen:
             await ward.disconnect()
 
 
-    def negotiate(self, client_type = None):
+    def negotiate(self):
+        self.loop = asyncio.get_event_loop()
+        if self.loop.is_running():
+            raise Exception("You cannot negotiate with an already running Event loop, please ue negotiate_async")
+
         self.loop.run_until_complete(self.negotiate_async())
 
 
@@ -312,10 +299,6 @@ class BaseBergen:
         await self.disconnect_async()
 
 
-
-    def negotiate(self):
-        self.loop.run_until_complete(self.negotiate_async())
-
     def disconnect(self):
         self.loop.run_until_complete(self.disconnect_async())
 
@@ -326,7 +309,7 @@ class BaseBergen:
 
     def __exit__(self, *args, **kwargs):
         self.disconnect()
-        
+
 
     
     @property
@@ -358,6 +341,12 @@ class BaseBergen:
         else:
             raise Exception("We are not in Provider Mode")
 
+    def template(self, *args, **kwargs):
+        if self._provider:
+            return self.provider.template(*args, **kwargs)
+        else:
+            raise Exception("We are not in Provider Mode")
+
     async def provide_async(self):
         return await self.provider.provide_async()
 
