@@ -23,10 +23,7 @@ class PointBergen(Bergen):
 
 
     def start(self):
-        if self.loop.is_running() and not self.running_in_sync: 
-             raise NotImplementedError("We cannot start in an Eventloop")
-        else:
-            self.negotiate()
+        self.negotiate()
 
         params = []
         for model in self.model_registry.values():
