@@ -1,134 +1,20 @@
-
-
-from abc import ABC, abstractmethod
-from asyncio.events import AbstractEventLoop
-from bergen.messages.postman.unprovide.unprovide_critical import UnprovideCriticalMessage
-from bergen.messages.postman.unprovide.unprovide_progress import UnprovideProgressMessage
-from bergen.messages.postman.provide.provide_critical import ProvideCriticalMessage
-from bergen.messages.postman.unprovide import BouncedUnprovideMessage, UnprovideDoneMessage
+from abc import abstractmethod
 from bergen.clients.base import BaseBergen
 from bergen.messages.base import MessageModel
 from bergen.hookable.base import Hookable, hookable
-from bergen.entertainer.actor import Actor, AsyncFuncActor, AsyncGenActor, ThreadedFuncActor
-from bergen.messages.postman.assign.assign import AssignMessage
+from bergen.actors.base import Actor
+from bergen.actors.functional import *
 from bergen.provider.utils import createNodeFromActor, createNodeFromFunction
 from bergen.console import console
 from pydantic.main import BaseModel
-from bergen.types.node import ports
-from typing import Dict, Tuple, TypedDict, Union
-from bergen.utils import ExpansionError, expandInputs, shrinkOutputs
-from bergen.schema import Template, NodeType
-from bergen.constants import ACCEPT_GQL, OFFER_GQL, SERVE_GQL
+from bergen.constants import OFFER_GQL
 import logging
-import namegenerator
 import asyncio
-import websockets
-from bergen.models import Node, Pod
+from bergen.models import Node
 import inspect
-import sys
-from aiostream import stream
-from concurrent.futures import ThreadPoolExecutor, ProcessPoolExecutor
-from functools import partial
+from bergen.messages import *
+
 logger = logging.getLogger()
-import copy
-import json
-from bergen.types.model import ArnheimModel
-import uuid
-from bergen.messages.postman.provide import BouncedProvideMessage, ProvideProgressMessage, BouncedCancelProvideMessage
-
-
-class BaseHelper(ABC):
-
-    def __init__(self, peasent) -> None:
-        self.peasent = peasent
-        pass
-
-    @abstractmethod
-    async def pass_yield(self, message, value):
-        pass
-
-    @abstractmethod
-    async def pass_progress(self, message, value, percentage=None):
-        pass
-
-    @abstractmethod
-    async def pass_result(self, message, value):
-        pass
-
-    @abstractmethod
-    async def pass_exception(self, message, exception):
-        pass
-
-
-class AssignationHelper():
-
-    def __init__(self, peasent_helper: BaseHelper, message: AssignMessage, loop: AbstractEventLoop = None) -> None:
-        self.peasent_helper = peasent_helper
-        self.message = message
-        self.loop = loop
-        pass
-
-    @abstractmethod
-    def progress(self, value, percentage=None):
-        pass
-
-
-
-class ThreadedAssignationHelper(AssignationHelper):
-
-    def progress(self, value, percentage=None):
-        logger.info(f'{percentage if percentage else "--"} : {value}')
-        if self.loop.is_running():
-            future = asyncio.run_coroutine_threadsafe(self.peasent_helper.pass_progress(self.message, value, percentage=percentage), self.loop)
-            return future.result()
-        else:
-            self.loop.run_until_complete(self.peasent_helper.pass_progress(self.message, value, percentage=percentage))
-
-
-class AsyncAssignationHelper(AssignationHelper):
-
-    async def progress(self, value, percentage=None):
-        logger.info(f'{percentage if percentage else "--"} : {value}')
-        await self.peasent_helper.pass_progress(self.message, value, percentage=percentage)
-
-
-
-async def shrink(node_template_pod, outputs):
-    kwargs = {}
-    if isinstance(node_template_pod, Node):
-        kwargs = await shrinkOutputs(node=node_template_pod, outputs=outputs)
-
-    if isinstance(node_template_pod, Template):
-        kwargs = await shrinkOutputs(node=node_template_pod.node, outputs=outputs)
-
-    if isinstance(node_template_pod, Pod):
-        kwargs = await shrinkOutputs(node=node_template_pod.template.node, outputs=outputs)
-
-
-    return kwargs
-
-
-
-async def expand(node_template_pod, inputs):
-    kwargs = {}
-    if isinstance(node_template_pod, Node):
-        kwargs = await expandInputs(node=node_template_pod, inputs=inputs)
-
-    if isinstance(node_template_pod, Template):
-        kwargs = await expandInputs(node=node_template_pod.node, inputs=inputs)
-
-    if isinstance(node_template_pod, Pod):
-        kwargs = await expandInputs(node=node_template_pod.template.node, inputs=inputs) 
-    return kwargs
-
-
-
-threadhelper = None
-try: 
-    threadhelper = asyncio.to_thread
-except:
-    logger.warn("Threading does not work below Python 3.9")
-
 
 
 class PodPolicy(BaseModel):
@@ -196,15 +82,17 @@ class BaseProvider(Hookable):
                 is_function = inspect.isfunction(function_or_actor)
 
                 if is_coroutine:
-                    actorClass =  type(f"GeneratedActorNode{node.id}",(AsyncFuncActor,), {"assign": function_or_actor})
+                    actorClass =  type(f"GeneratedActor{template.id}",(FunctionalFuncActor,), {"assign": staticmethod(function_or_actor)})
                 elif is_asyncgen:
-                    actorClass =  type(f"GeneratedActorNode{node.id}",(AsyncGenActor,), {"assign": function_or_actor})
+                    actorClass =  type(f"GeneratedActor{template.id}",(FunctionalGenActor,), {"assign": staticmethod(function_or_actor)})
                 elif is_function:
-                    actorClass = type(f"GeneratedActorNode{node.id}",(ThreadedFuncActor,), {"assign": function_or_actor})
+                    actorClass = type(f"GeneratedActor{template.id}",(FunctionalThreadedFuncActor,), {"assign": staticmethod(function_or_actor)})
                 else:
                     raise Exception(f"Unknown type of function {function_or_actor}")
             
-            self.template_actorClass_map[str(template.id)] = actorClass
+
+            self.register_actor(str(template.id), actorClass)
+
             return actorClass
 
         return real_decorator
@@ -307,23 +195,24 @@ class BaseProvider(Hookable):
 
     @hookable("bounced_provide", overwritable=True)
     async def on_bounced_provide(self, message: BouncedProvideMessage):
-        pod, task = await self.provideTemplate(message, message.data.template)
-        self.provisions[message.meta.reference] = task # Run in parallel
+        actorClass = await self.get_actorclass_for_template(message.data.template)
+        console.log(f"[red]Got provision request for {message.data.template} and will entertain {actorClass.__name__}")
+        await self.client.entertainer.entertain(message, actorClass) # Run in parallel
 
     @hookable("bounced_unprovide", overwritable=True)
     async def on_bounced_unprovide(self, message: BouncedUnprovideMessage):
-        logger.error("Overwrite me")
-
-
-    
-    async def provideTemplate(self, message, template_id: str):
-        assert template_id in self.template_actorClass_map, f"There is no function registered for this template {template_id} not it {self.template_actorClass_map.keys()}"
-            
-        actorClass = self.template_actorClass_map[template_id]
-        self.client.entertainer.registerActor(template_id, actorClass)
-        return await self.client.entertainer.entertain(message)
+        console.log(f"[red]Got unprovision. Sending to entertainer")
+        await self.client.entertainer.unentertain(message)
 
+    @hookable("get_actorclass_for_template", overwritable=True)
+    async def get_actorclass_for_template(self, template_id):
+        assert template_id in self.template_actorClass_map, f"We have no Actor stored in our list {template_id}"
+        return self.template_actorClass_map[template_id]
 
+    def register_actor(self, template_id: str, actorClass: Type[Actor]):
+        assert template_id not in self.template_actorClass_map, f"We cannot register two Actors for the same template {template_id}"
+        self.template_actorClass_map[template_id] = actorClass
+        console.log(f"[red]Registered Actor {actorClass.__name__} for Template {template_id}")
 
     async def provide_async(self):
         while True:
