@@ -34,16 +34,12 @@ class BaseGraphQLWard(BaseWard, ABC):
 
     
     def run(self, the_query: TypedGQL, variables: dict = {}, **kwargs):
-        if self.loop.is_running():
-            # We are alredy doing some weird shit
-            query_node = gql(the_query.query)
-            response = self.sync_transport.execute(query_node, variable_values=variables)
-            if response.errors:
-                raise GraphQLException(f"Error: {self._graphql_endpoint} {str(response.errors)}")
-            return the_query.extract(response.data)
+        query_node = gql(the_query.query)
+        response = self.sync_transport.execute(query_node, variable_values=variables)
+        if response.errors:
+            raise GraphQLException(f"Error: {self._graphql_endpoint} {str(response.errors)} called with Query {query_node} and variables {variables}")
+        return the_query.extract(response.data)
 
-        else:
-            return self.loop.run_until_complete(self.run_async(the_query, variables=variables, **kwargs))
 
 
 
